@@ -53,22 +53,23 @@ class MatchRouter( Plugin ):
     **map file specification,**
 
     .. code-block:: python
+        :linenos:
 
-      [ { 'name'             : <variant-name as string>,
-          'pattern'          : <regex pattern-to-match-with-request-URL>,
-          'view'             : <view-callable as string>,
-          'resource'         : <resource-name as string>,
-          'attr'             : <attribute on view callable, as string>,
-          'method'           : <HTTP request method as byte string>,
-          'media_type'       : <content-type as string>,
-          'language'         : <language-string as string>,
-          'charset'          : <charset-string as string>,
-          'content_coding'   : <content-coding as comma separated values>,
-          'cache_control'    : <response header value>,
-          'rootloc'          : <path to root location for static documents>,
-        },
-        ...
-      ]
+        [ { 'name'             : <variant-name as string>,
+            'pattern'          : <regex pattern-to-match-with-request-URL>,
+            'view'             : <view-callable as string>,
+            'resource'         : <resource-name as string>,
+            'attr'             : <attribute on view callable, as string>,
+            'method'           : <HTTP request method as byte string>,
+            'media_type'       : <content-type as string>,
+            'language'         : <language-string as string>,
+            'charset'          : <charset-string as string>,
+            'content_coding'   : <content-coding as comma separated values>,
+            'cache_control'    : <response header value>,
+            'rootloc'          : <path to root location for static documents>,
+          },
+          ...
+        ]
     """
 
     implements( IHTTPRouter )
@@ -94,8 +95,7 @@ class MatchRouter( Plugin ):
         self.viewlist = []
         self.negotiator = None
         if self['IHTTPNegotiator'] :
-            self.negotiator = \
-                self.query_plugin( IHTTPNegotiator, self['IHTTPNegotiator'] )
+            self.negotiator = self.qp(IHTTPNegotiator, self['IHTTPNegotiator'])
         self['defaultview'] = h.string_import( self['defaultview'] )
 
         # Route mapping file is configured, populate view-callables from the
@@ -125,6 +125,7 @@ class MatchRouter( Plugin ):
         For EG,
 
         .. code-block:: python
+            :linenos:
 
             self.add_view( 'article', 'blog/{year}/{month}/{date}' )
 
@@ -320,7 +321,7 @@ class MatchRouter( Plugin ):
         v = viewd['view']
         self.pa.logdebug( "%r view callable: %r " % (request.uri, v) )
         if isinstance(v, str) and isplugin(v) :
-            view = self.query_plugin( IHTTPView, v, name, viewd )
+            view = self.qp( IHTTPView, v, name, viewd )
         elif isinstance( v, str ):
             view = h.string_import( v )
         else :
@@ -332,7 +333,7 @@ class MatchRouter( Plugin ):
         res = viewd['resource']
         self.pa.logdebug( "%r resource callable: %r " % (request.uri, res) )
         if isinstance( res, str ) and isplugin( res ) :
-            return self.query_plugin( IHTTPResource, res )
+            return self.qp( IHTTPResource, res )
         elif isinstance( res, str ) :
             return h.string_import( res )
         else :
@@ -452,7 +453,7 @@ _default_settings['defaultview']  = {
                 "cannot be resolved to a valid view-callable."
 }
 _default_settings['IHTTPNegotiator']  = {
-    'default' : 'HTTPNegotiator',
+    'default' : 'pluggdapps.HTTPNegotiator',
     'types'   : (str,),
     'help'    : "If configured, will be used to handle server side http "
                 "negotiation for best matching resource variant."
